==> service_layer_rest-0.1.34.gem: app/controllers/service_layer_rest/staff_schedulings/daily_data_controller.rb <==
module ServiceLayerRest
  module StaffSchedulings
    class DailyDataController < ApplicationController
      include Base
      include Dll

      #TODO: remove time_... stuff

      def create_daily_data_services
        handle_daily_data_services
      end

      def update_daily_data_services
        handle_daily_data_services
      end

      def delete_daily_data_services
        handle_daily_data_services
      end

      def create_daily_data_standbys
        handle_daily_data_standbys
      end

      def update_daily_data_standbys
        handle_daily_data_standbys
      end

      def delete_daily_data_standbys
        handle_daily_data_standbys
      end

      def create_daily_data_states
        handle_daily_data_states
      end

      def update_daily_data_states
        handle_daily_data_states
      end

      def delete_daily_data_states
        handle_daily_data_states
      end

      def update_daily_data_attributes
        invalid_key = check_params([:fct_code], [])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        checked_params = check_params_for_tlist(params, :change_tel_list, 'zu ändernden TEL-Details')
        return render checked_params unless checked_params == true

        begin
          response_string, string_pointer = ServiceLayerDll.update_staff_scheduling_daily_data_attributes(
              current_user.as_json,
              params[:fct_code],
              params[:change_tel_list].to_json
          )
          ServiceLayerDll.free_string(string_pointer)

          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      def get_daily_data_servicedefinitions
        invalid_key = check_params([:fct_code, :date], [:planarea_id, :employee_id])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        begin
          response_string, string_pointer = ServiceLayerDll.get_staff_scheduling_daily_data_servicedefinitions(
              current_user.as_json,
              params[:fct_code],
              params[:planarea_id].to_i,
              params[:employee_id].to_i,
              params[:date]
          )
          ServiceLayerDll.free_string(string_pointer)
          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      def get_daily_data_standbydefinitions
        invalid_key = check_params([:fct_code, :date], [:planarea_id, :employee_id])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        begin
          response_string, string_pointer = ServiceLayerDll.get_staff_scheduling_daily_data_standbydefinitions(
              current_user.as_json,
              params[:fct_code],
              params[:planarea_id].to_i,
              params[:employee_id].to_i,
              params[:date]
          )
          ServiceLayerDll.free_string(string_pointer)
          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      def get_daily_data_statedefinitions
        invalid_key = check_params([:fct_code, :date], [:planarea_id, :employee_id])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        begin
          response_string, string_pointer = ServiceLayerDll.get_staff_scheduling_daily_data_statedefinitions(
              current_user.as_json,
              params[:fct_code],
              params[:planarea_id].to_i,
              params[:employee_id].to_i,
              params[:date]
          )
          ServiceLayerDll.free_string(string_pointer)
          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      def get_daily_data_colordefinitions
        invalid_key = check_params([:fct_code, :date], [:planarea_id, :employee_id])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        begin
          response_string, string_pointer = ServiceLayerDll.get_staff_scheduling_daily_data_colordefinitions(
              current_user.as_json,
              params[:fct_code],
              params[:planarea_id].to_i,
              params[:employee_id].to_i,
              params[:date]
          )
          ServiceLayerDll.free_string(string_pointer)
          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      private
      def handle_daily_data_services
        invalid_key = check_params([:fct_code], [])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        checked_params = check_params_for_tlist(params, :add_tel_list, 'einzutragenden Dienste')
        return render checked_params unless checked_params == true

        return render bad_params_for_render('as_wish') unless params.has_key?('as_wish')

        time_marker_all = start_timer
        begin
          time_marker_dll = start_timer
          response_string, string_pointer = ServiceLayerDll.handle_staff_scheduling_daily_data_services(
              current_user.as_json,
              params[:fct_code],
              params[:add_tel_list].to_json,
              params[:as_wish].to_s == 'true'
          )
          ServiceLayerDll.free_string(string_pointer)
          stop_timer(time_marker_dll, "Rails Duration (Dll)")

          time_marker_render = start_timer
          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
          stop_timer(time_marker_render, "Rails Duration (Render)")
        rescue Exception => e
          time_marker_render = start_timer
          render parse_exception_for_render(e)
          stop_time(time_marker_render, "Rails Duration (Render)")
        end
        stop_timer(time_marker_all, "Rails Duration (All)")
      end

      def handle_daily_data_standbys
        invalid_key = check_params([:fct_code], [])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        checked_params = check_params_for_tlist(params, :add_tel_list, 'einzutragenden Bereitschaften')
        return render checked_params unless checked_params == true
        
        return render bad_params_for_render('as_wish') unless params.has_key?('as_wish')

        begin
          response_string, string_pointer = ServiceLayerDll.handle_staff_scheduling_daily_data_standbys(
              current_user.as_json,
              params[:fct_code],
              params[:add_tel_list].to_json,
              params[:as_wish].to_s == 'true'
          )
          ServiceLayerDll.free_string(string_pointer)

          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      def handle_daily_data_states
        invalid_key = check_params([:fct_code], [])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        checked_params = check_params_for_tlist(params, :add_tel_list, 'einzutragenden Status')
        return render checked_params unless checked_params == true

        return render bad_params_for_render('as_wish') unless params.has_key?('as_wish')

        begin
          response_string, string_pointer = ServiceLayerDll.handle_staff_scheduling_daily_data_states(
              current_user.as_json,
              params[:fct_code],
              params[:add_tel_list].to_json,
              params[:as_wish].to_s == 'true'
          )
          ServiceLayerDll.free_string(string_pointer)

          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end
    end
  end
end

==> service_layer_rest-0.1.47.gem: app/controllers/service_layer_rest/staff_schedulings/daily_data_controller.rb <==
module ServiceLayerRest
  module StaffSchedulings
    class DailyDataController < ApplicationController
      include ServiceLayerHelper
      include Base
      include Dll

      #TODO: remove time_... stuff

      def create_daily_data_services
        handle_daily_data_services
      end

      def update_daily_data_services
        handle_daily_data_services
      end

      def delete_daily_data_services
        handle_daily_data_services
      end

      def create_daily_data_standbys
        handle_daily_data_standbys
      end

      def update_daily_data_standbys
        handle_daily_data_standbys
      end

      def delete_daily_data_standbys
        handle_daily_data_standbys
      end

      def create_daily_data_states
        handle_daily_data_states
      end

      def update_daily_data_states
        handle_daily_data_states
      end

      def delete_daily_data_states
        handle_daily_data_states
      end

      def update_daily_data_attributes
        invalid_key = check_params([], [:fct_code])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        checked_params = check_params_for_tlist(params, :change_tel_list, 'zu ändernden TEL-Details')
        return render checked_params unless checked_params == true

        begin
          response_string, string_pointer = ServiceLayerDll.update_staff_scheduling_daily_data_attributes(
              current_user.as_json,
              params[:fct_code].to_i,
              params[:change_tel_list].to_json
          )
          ServiceLayerDll.free_string(string_pointer)

          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      def get_daily_data_servicedefinitions
        invalid_key = check_params([:date], [:fct_code, :planarea_id, :employee_id])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        begin
          response_string, string_pointer = ServiceLayerDll.get_staff_scheduling_daily_data_servicedefinitions(
              current_user.as_json,
              params[:fct_code].to_i,
              params[:planarea_id].to_i,
              params[:employee_id].to_i,
              params[:date]
          )
          ServiceLayerDll.free_string(string_pointer)
          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      def get_daily_data_standbydefinitions
        invalid_key = check_params([:date], [:fct_code, :planarea_id, :employee_id])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        begin
          response_string, string_pointer = ServiceLayerDll.get_staff_scheduling_daily_data_standbydefinitions(
              current_user.as_json,
              params[:fct_code].to_i,
              params[:planarea_id].to_i,
              params[:employee_id].to_i,
              params[:date]
          )
          ServiceLayerDll.free_string(string_pointer)
          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      def get_daily_data_statedefinitions
        invalid_key = check_params([:date], [:fct_code, :planarea_id, :employee_id])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        begin
          response_string, string_pointer = ServiceLayerDll.get_staff_scheduling_daily_data_statedefinitions(
              current_user.as_json,
              params[:fct_code].to_i,
              params[:planarea_id].to_i,
              params[:employee_id].to_i,
              params[:date]
          )
          ServiceLayerDll.free_string(string_pointer)
          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      def get_daily_data_colordefinitions
        invalid_key = check_params([:date], [:fct_code, :planarea_id, :employee_id])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        begin
          response_string, string_pointer = ServiceLayerDll.get_staff_scheduling_daily_data_colordefinitions(
              current_user.as_json,
              params[:fct_code].to_i,
              params[:planarea_id].to_i,
              params[:employee_id].to_i,
              params[:date]
          )
          ServiceLayerDll.free_string(string_pointer)
          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      private
      def handle_daily_data_services
        invalid_key = check_params([], [:fct_code])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        checked_params = check_params_for_tlist(params, :add_tel_list, 'einzutragenden Dienste')
        return render checked_params unless checked_params == true

        return render bad_params_for_render('as_wish') unless params.has_key?('as_wish')

        time_marker_all = start_timer
        begin
          time_marker_dll = start_timer
          response_string, string_pointer = ServiceLayerDll.handle_staff_scheduling_daily_data_services(
              current_user.as_json,
              params[:fct_code].to_i,
              params[:add_tel_list].to_json,
              params[:as_wish].to_s == 'true'
          )
          ServiceLayerDll.free_string(string_pointer)
          stop_timer(time_marker_dll, "Rails Duration (Dll)")

          time_marker_render = start_timer
          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
          stop_timer(time_marker_render, "Rails Duration (Render)")
        rescue Exception => e
          time_marker_render = start_timer
          render parse_exception_for_render(e)
          stop_time(time_marker_render, "Rails Duration (Render)")
        end
        stop_timer(time_marker_all, "Rails Duration (All)")
      end

      def handle_daily_data_standbys
        invalid_key = check_params([], [:fct_code])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        checked_params = check_params_for_tlist(params, :add_tel_list, 'einzutragenden Bereitschaften')
        return render checked_params unless checked_params == true
        
        return render bad_params_for_render('as_wish') unless params.has_key?('as_wish')

        begin
          response_string, string_pointer = ServiceLayerDll.handle_staff_scheduling_daily_data_standbys(
              current_user.as_json,
              params[:fct_code].to_i,
              params[:add_tel_list].to_json,
              params[:as_wish].to_s == 'true'
          )
          ServiceLayerDll.free_string(string_pointer)

          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end

      def handle_daily_data_states
        invalid_key = check_params([], [:fct_code])
        return render bad_params_for_render(invalid_key) unless invalid_key.blank?

        checked_params = check_params_for_tlist(params, :add_tel_list, 'einzutragenden Status')
        return render checked_params unless checked_params == true

        return render bad_params_for_render('as_wish') unless params.has_key?('as_wish')

        begin
          response_string, string_pointer = ServiceLayerDll.handle_staff_scheduling_daily_data_states(
              current_user.as_json,
              params[:fct_code].to_i,
              params[:add_tel_list].to_json,
              params[:as_wish].to_s == 'true'
          )
          ServiceLayerDll.free_string(string_pointer)

          render parse_response_string_for_render(response_string.force_encoding('utf-8'))
        rescue Exception => e
          render parse_exception_for_render(e)
        end
      end
    end
  end
end
